import vjmap from "vjmap"
import { attachMap } from "vjchat"
import { config } from "./config"
import { ElMessage } from "element-plus"
export const initMap = async () => {
    // 地图服务对象
    let svc = new vjmap.Service(config.serviceUrl, config.accessToken)
    // 打开地图
    let res = await svc.openMap({
        mapid: config.mapId, // 地图ID
        version: config.mapVersion, // 地图版本
        mapopenway: config.mapopenway || vjmap.MapOpenWay.GeomRender, // 以几何数据渲染方式打开
        style: vjmap.openMapDarkStyle() // div为深色背景颜色时，这里也传深色背景样式
    })
    if (res.error) {
        // 如果打开出错
        ElMessage.error(res.error)
        return;
    }
    // 获取地图范围
    let mapExtent = vjmap.GeoBounds.fromString(res.bounds);
    // 根据地图范围建立几何投影坐标系
    let prj = new vjmap.GeoProjection(mapExtent);

    // 地图对象
    let map = new vjmap.Map({
        container: "map-container", // DIV容器ID
        style: svc.rasterStyle(), // // 栅格瓦片样式
        center: prj.toLngLat(mapExtent.center()), // 设置地图中心点
        zoom: 2, // 设置地图缩放级别,
        pitch: 0, // 倾斜角度
        renderWorldCopies: false // 不显示多屏地图
    });
    
    // 关联服务对象和投影对象
    map.attach(svc, prj);
    // 根据地图本身范围缩放地图至全图显示
    //map.fitMapBounds();
    await map.onLoad(); // 等待地图加载完成
    
    return map;
}

export const initChat =  (map: vjmap.Map) => {
    return attachMap(map, vjmap, {
        silent: true,
        disableUndoRecord: true,
        buttonControl: {
            position: "top-left",
            left: 60,
            top: 0
        }
    })
}
